@@ -197,13 +197,11 @@ def get_cube(cube, path=None):
     '''
     Wraps __import__ to dynamically locate and load a client cube.
 
-    :param string module:
-        Module name (eg, 'jkns.build')
     :param string cube:
         Name of the cube Class to be imported from given module (eg, 'Build')
+    :param string path:
+        path to look for cubes (eg '~/.metrique/cubes/')
     '''
-    if not path:
-        path = DEFAULT_CLIENT_CUBES_PATH
     set_cube_path(path)
     pkg, mod, cls = cube_pkg_mod_cls(cube)
     _pkg = __import__(pkg, fromlist=[mod])
